# OctoPrintClientStatusRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**subject_pattern** | [**OctoPrintClientStatusSubjectPatternEnum**](OctoPrintClientStatusSubjectPatternEnum.md) |  | 
**payload** | [**OctoPrintClientStatusPayloadRequest**](OctoPrintClientStatusPayloadRequest.md) |  | 
**event_type** | [**OctoPrintClientStatusType**](OctoPrintClientStatusType.md) |  | 
**octoprint_server** | **int** |  | 
**pi** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


